
library (gplots)
require(plotrix)

# read experimental data (replace <PATH> with location of /DatasetS1 directory)

EXPT1 <-read.table("<PATH>/DatasetS1/Fig2-EXPT1.csv",header = TRUE,sep=",");
EXPT2 <-read.table("<PATH>/DatasetS1/Fig3-EXPT2.csv",header = TRUE,sep=",");


plotExpts <- function(timeoffsetExp1,timeoffsetExp2) {
# plot expt 1 data and simulation
  quartz(width=4,height=4)
  par(yaxt="n")
  par(mar=c(3,3,2,3))
  plotCI(EXPT1$time,EXPT1$A_MRNA,xlim=c(150,750),ylim=c(0,60),main="",pch=16,col="black",uiw=EXPT1$A_MRNA_SD/sqrt(3),
         liw=EXPT1$A_MRNA_SD/sqrt(3),mai=c(3, 2, 2, 3),lwd=2)
  lines(SIMExp1$time-timeoffsetExp1+180,SIMExp1$A_MRNA,col="black",lwd=2)
  plotCI(EXPT1$time,EXPT1$A_PRE*10,pch=17,col="blue",uiw=EXPT1$A_PRE_SD/sqrt(3)*10, liw=EXPT1$A_PRE_SD/sqrt(3)*10,add=TRUE,lwd=2)
  lines(SIMExp1$time-timeoffsetExp1+180,SIMExp1$A_PRE*10,col="blue",lwd=2)
  plotCI(EXPT1$time,EXPT1$A_LARIATEXON2,pch=15,col="darkgreen",uiw=EXPT1$A_LARIATEXON2_SD/sqrt(3), liw=EXPT1$A_LARIATEXON2_SD/sqrt(3),add=TRUE,lwd=2)
  lines(SIMExp1$time-timeoffsetExp1+180,SIMExp1$A_LARIATEXON2,col="darkgreen",lwd=2)
  
  par(xaxt="s")
  par(yaxt="s")
  axis(s=4,xaxp=c(0,60,7),at=c(0,10,20,30,40,50,60),labels=c("0","10","20","30","40","50","60"))
  axis(s=2,xaxp=c(0,6,7),at=c(0,10,20,30,40,50,60),labels=c("0","1","2","3","4","5","6"))
  mtext("Time (s)",side=1,line=2)
  mtext("lariat-exon2 / mRNA (Copies/Cell)",side=4,line=2)
  mtext("pre-mRNA (Copies/Cell)",side=2,line=2)
  legend(x="topleft",bty="n",legend=c("A-pre-mRNA","A-lariat-exon2","A-mRNA"),pch=c(-1,-1,-1),lty=c(1,1,1),lwd=2,col=c("blue","darkgreen","black"))
  
# plot expt 2 data and simulation

  quartz(width=4,height=4)
  par(yaxt="n")
  par(mar=c(3,3,2,3))
  plotCI(EXPT2$time,EXPT2$U_PRE,col="blue",uiw=EXPT2$U_PRE_SE,liw=EXPT2$U_PRE_SE,pch=16,xlim=c(400,700),ylim=c(0,12),lwd=2)
  plotCI(EXPT2$time,EXPT2$P_PRE,col="purple",uiw=EXPT2$P_PRE_SE,liw=EXPT2$P_PRE_SE,nalPolyASE,pch=17,add=TRUE,lwd=2)
  plotCI(EXPT2$time,EXPT2$P_LARIATEXON2,col="red",uiw=EXPT2$P_LARIATEXON2_SE,liw=EXPT2$P_LARIATEXON2_SE,pch=15,add=TRUE,lwd=2)
  lines(SIMExp2$time+timeoffsetExp2,SIMExp2$U_PRE,col="blue",lwd=2)
  lines(SIMExp2$time+timeoffsetExp2,SIMExp2$P_PRE,col="purple",lwd=2)
  lines(SIMExp2$time+timeoffsetExp2,SIMExp2$P_LARIATEXON2,col="red",lwd=2)
  par(xaxt="s")
  par(yaxt="s")
  axis(s=2,xaxp=c(0,12,7),at=c(0,2,4,6,8,10,12),labels=c("0","2","4","6","8","10","12"))
  axis(s=4,xaxp=c(0,12,7),at=c(0,2,4,6,8,10,12),labels=c("0","2","4","6","8","10","12"))
  lines(SIMExp2$time+timeoffsetExp2,SIMExp2$P_LARIATEXON2,col="red",lwd=2)
  mtext("Time (s)",side=1,line=2)
  mtext("pre-mRNA (Copies/Cell)",side=2,line=2)
  mtext("polyadenylated lariat-exon2 (Copies/Cell)",side=4,line=2)
  legend(x="topleft",bty="n",legend=c("U-pre-mRNA","P-pre-mRNA","P-lariat-exon2"),pch=c(-1,-1,-1),lty=c(1,1,1),lwd=2,col=c("blue","purple","red"))
  
  
  
  quartz(width=4,height=4)
  par(yaxt="n")
  par(mar=c(3,3,2,3))
  plotCI(EXPT2$time,EXPT2$P_MRNA,xlim=c(400,700),ylim=c(0,40),main="",col="black",uiw=EXPT2$P_MRNA_SE,
         liw=EXPT2$P_MRNA_SE,mai=c(3, 2, 2, 3),pch=16,lwd=2)
  plotCI(EXPT2$time,EXPT2$U_LARIATEXON2,col="red",uiw=EXPT2$U_LARIATEXON2_SE,
         liw=EXPT2$U_LARIATEXON2_SE,pch=17,xlim=c(400,700),ylim=c(0,12),add=TRUE,lwd=2)
  plotCI(EXPT2$time,EXPT2$U_MRNA,main="",col="darkgreen",uiw=EXPT2$U_MRNA_SE,
         liw=EXPT2$U_MRNA_SE,mai=c(3, 2, 2, 3),pch=15,add=TRUE,lwd=2)
  
  lines(SIMExp2$time+timeoffsetExp2,SIMExp2$P_MRNA,col="black",lwd=2)
  lines(SIMExp2$time+timeoffsetExp2,SIMExp2$U_LARIATEXON2,col="red",lwd=2)
  lines(SIMExp2$time+timeoffsetExp2,SIMExp2$U_MRNA,col="darkgreen",lwd=2)
  par(xaxt="s")
  par(yaxt="s")
  axis(s=2,xaxp=c(0,60,7),at=c(0,10,20,30,40,50,60),labels=c("0","10","20","30","40","50","60"))
  axis(s=4,xaxp=c(0,60,7),at=c(0,10,20,30,40,50,60),labels=c("0","10","20","30","40","50","60"))
  mtext("Time (s)",side=1,line=2)
  mtext("uncleaved lariat-exon2 (Copies/Cell)",side=2,line=2)
  mtext("mRNA (Copies/Cell)",side=4,line=2)
  legend(x="topleft",bty="n",legend=c("U-lariat-exon2","U-mRNA","P-mRNA"),pch=c(-1,-1,-1),lty=c(1,1,1),lwd=2,col=c("red","darkgreen","black"))
}

# use simulator to generate model-X.csv files

# model I
SIMExp1 <-read.table("<PATH>/DatasetS1/model-I-Exp1.csv",header = TRUE,sep=",");
SIMExp2 <-read.table("<PATH>/DatasetS1/model-I-Exp2.csv",header = TRUE,sep=",");
plotExpts(350,40);

# model I
SIMExp1 <-read.table("<PATH>/DatasetS1/model-I-Exp1.csv",header = TRUE,sep=",");
SIMExp2 <-read.table("<PATH>/DatasetS1/model-I-Exp2.csv",header = TRUE,sep=",");
plotExpts(350,40);

# model II
SIMExp1 <-read.table("<PATH>/DatasetS1/model-II-Exp1.csv",header = TRUE,sep=",");
SIMExp2 <-read.table("<PATH>/DatasetS1/model-II-Exp2.csv",header = TRUE,sep=",");
plotExpts(340,60);

# model III
SIMExp1 <-read.table("<PATH>/DatasetS1/model-III-Exp1.csv",header = TRUE,sep=",");
SIMExp2 <-read.table("<PATH>/DatasetS1/model-III-Exp2.csv",header = TRUE,sep=",");
plotExpts(350,40);

# model IV
SIMExp1 <-read.table("<PATH>/DatasetS1/model-IV-Exp1.csv",header = TRUE,sep=",");
SIMExp2 <-read.table("<PATH>/DatasetS1/model-IV-Exp2.csv",header = TRUE,sep=",");
plotExpts(330,50);

# model V
SIMExp1 <-read.table("<PATH>/DatasetS1/model-V-Exp1.csv",header = TRUE,sep=",");
SIMExp2 <-read.table("<PATH>/DatasetS1/model-V-Exp2.csv",header = TRUE,sep=",");
plotExpts(370,40);

# model VI
SIMExp1 <-read.table("<PATH>/DatasetS1/model-VI-Exp1.csv",header = TRUE,sep=",");
SIMExp2 <-read.table("<PATH>/DatasetS1/model-VI-Exp2.csv",header = TRUE,sep=",");
plotExpts(340,60);

# model VII
SIMExp1 <-read.table("<PATH>/DatasetS1/model-VII-Exp1.csv",header = TRUE,sep=",");
SIMExp2 <-read.table("<PATH>/DatasetS1/model-VII-Exp2.csv",header = TRUE,sep=",");
plotExpts(340,50);

# model VIII
SIMExp1 <-read.table("<PATH>/DatasetS1/model-VIII-Exp1.csv",header = TRUE,sep=",");
SIMExp2 <-read.table("<PATH>/DatasetS1/model-VIII-Exp2.csv",header = TRUE,sep=",");
plotExpts(310,60);

